@@ -15,6 +15,7 @@ use std::fmt;
 /// The `Command` struct defines fields that hold parsed command line argument data and provides methods that can be used to define the logic of a command line interface application.
 ///
 /// # Examples
+///
 /// ## Instantiation
 ///
 /// ```norun
@@ -27,6 +28,16 @@ use std::fmt;
 /// }
 /// ```
 ///
+/// ## Debugging
+///
+/// The `Command` struct supports pretty-printed display of all parsed data fields to the standard output stream with the `{:#?}` formatting idiom:
+///
+/// ```
+/// use commandlines::Command;
+///
+/// println!("{:#?}", Command::new());
+/// ```
+///
 /// # Remarks
 ///
 /// The Vector of command line arguments presented to the executable in `std::env::args().collect()` is used to define the `Command` struct fields.
@@ -44,6 +55,10 @@ pub struct Command {
     pub options: Vec<String>,
     /// HashMap of command line option definitions mapped as key=option:value=definition
     pub definitions: HashMap<String, String>,
+    /// `Option<String>` of first positional argument to the executable. `None` if there are no arguments to the executable.
+    pub first_arg: Option<String>,
+    /// `Option<String>` of last positional argument to the executable. `None` if there are no arguments to the executable.
+    pub last_arg: Option<String>,
 }
 
 // Traits
@@ -110,6 +125,8 @@ impl Command {
         let size_definition = arguments.len();
         let vec_options = parsers::parse_options(&arguments);
         let definitions_hm = parsers::parse_definitions(&arguments);
+        let first_arg_definition = parsers::parse_first_arg(&arguments);
+        let last_arg_definition = parsers::parse_last_arg(&arguments);
 
         Command {
             argv: arguments_definition,
@@ -117,6 +134,8 @@ impl Command {
             executable: executable_definition.to_string(),
             options: vec_options,
             definitions: definitions_hm,
+            first_arg: first_arg_definition,
+            last_arg: last_arg_definition,
         }
     }
 
@@ -131,7 +150,7 @@ impl Command {
     /// let c = commandlines::Command::new();
     ///
     /// if !c.has_args() {
-    ///    eprintln!("{}", "Missing arguments");
+    ///    eprintln!("Missing arguments");
     /// }
     /// ```
     pub fn has_args(&self) -> bool {
@@ -227,6 +246,46 @@ impl Command {
         self.options.contains(&String::from(needle))
     }
 
+    /// Returns a boolean for the question "Does the command include all of the option strings in `needle_vec` Vector?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.contains_all_options(vec!["--some", "--things"]) {
+    ///     // implement whatever requires `some` && `things` condition
+    /// }
+    /// ```
+    pub fn contains_all_options(&self, needle_vec: Vec<&str>) -> bool {
+        for needle in needle_vec {
+            if !self.options.contains(&needle.to_string()) {
+                return false;
+            }
+        }
+        true
+    }
+
+    /// Returns a boolean for the question "Does the command include any of the option strings in the `needle_vec` Vector?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.contains_any_option(vec!["-h", "--help"]) {
+    ///     // received a help request with `-h` || `--help` condition
+    /// }
+    /// ```
+    pub fn contains_any_option(&self, needle_vec: Vec<&str>) -> bool {
+        for needle in needle_vec {
+            if self.options.contains(&needle.to_string()) {
+                return true;
+            }
+        }
+        false
+    }
+
     /// Returns Option<&String> definition for a key defined by `needle`
     ///
     /// Returns `None` if the option was not used in the command
@@ -240,14 +299,14 @@ impl Command {
     ///
     /// match c.get_definition_for("--name") {
     ///     Some(x) => println!("The definition for --name is {}", *x),
-    ///     None => eprintln!("{}", "Missing")
+    ///     None => eprintln!("Missing")
     /// };
     /// ```
     pub fn get_definition_for(&self, needle: &str) -> Option<&String> {
         self.definitions.get(&String::from(needle))
     }
 
-    /// Returns `Option<&String>` for argument at index position i+1 for `needle` at index position i
+    /// Returns `Option<&String>` for argument at index position `i+1` for `needle` at index position `i`
     ///
     /// Returns `None` if `needle` is the last positional argument in the command
     ///
@@ -289,7 +348,7 @@ impl Command {
     ///
     /// match c.get_argument_at(0) {
     ///     Some(x) => println!("The executable is {}", *x),
-    ///     None => eprintln!("Error.")
+    ///     None => eprintln!("Error")
     /// }
     ///
     /// match c.get_argument_at(1) {
@@ -385,6 +444,38 @@ mod tests {
         assert_eq!(c.definitions, expected_hm);
     }
 
+    #[test]
+    fn command_instantiation_first_arg_field() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--help".to_string(),
+            "arg".to_string(),
+        ]);
+        assert_eq!(c.first_arg, Some(String::from("--help")));
+    }
+
+    #[test]
+    fn command_instantiation_first_arg_field_executable_only() {
+        let c = Command::new_with_vec(vec!["test".to_string()]);
+        assert_eq!(c.first_arg, None);
+    }
+
+    #[test]
+    fn command_instantiation_last_arg_field() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--help".to_string(),
+            "arg".to_string(),
+        ]);
+        assert_eq!(c.last_arg, Some(String::from("arg")));
+    }
+
+    #[test]
+    fn command_instantiation_last_arg_field_executable_only() {
+        let c = Command::new_with_vec(vec!["test".to_string()]);
+        assert_eq!(c.last_arg, None);
+    }
+
     #[test]
     fn command_method_has_args_true() {
         let c = Command::new_with_vec(vec!["test".to_string(), "--help".to_string()]);
@@ -467,6 +558,38 @@ mod tests {
         assert_eq!(c.contains_option("help"), false); // must include the option indicator in string
     }
 
+    #[test]
+    fn command_method_contains_all_options() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "subcmd".to_string(),
+            "--help".to_string(),
+            "--more".to_string(),
+        ]);
+        assert_eq!(c.contains_all_options(vec!["--more", "--help"]), true);
+        assert_eq!(c.contains_all_options(vec!["--help", "--bogus"]), false);
+        assert_eq!(c.contains_all_options(vec!["--bogus"]), false);
+        assert_eq!(c.contains_all_options(vec!["subcmd"]), false); // not an option, should not be included in test
+    }
+
+    #[test]
+    fn command_method_contains_any_option() {
+        let c1 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "subcmd".to_string(),
+            "--help".to_string(),
+        ]);
+        let c2 = Command::new_with_vec(vec![
+            "test".to_string(),
+            "subcmd".to_string(),
+            "-h".to_string(),
+        ]);
+        assert_eq!(c1.contains_any_option(vec!["--help", "-h"]), true);
+        assert_eq!(c2.contains_any_option(vec!["--help", "-h"]), true);
+        assert_eq!(c1.contains_any_option(vec!["--bogus", "-t"]), false);
+        assert_eq!(c1.contains_any_option(vec!["subcmd", "bogus"]), false);
+    }
+
     #[test]
     fn command_method_get_definition_for_def_present() {
         let c = Command::new_with_vec(vec![
